import os

__all__ = ['gui','fitting','backend']
__version__ = '2.9.2222222222222222222222'
__author__ = 'Derek Fujimoto'
logger_name = 'bfit'
icon_path = os.path.join(os.path.dirname(__file__),'images','icon.gif')
